2.6.24-rc8 ppp regression
Subsystems (2)
when killing a wvdial usb modem session:
Jan 22 23:23:03 dual pppd[7941]: Terminating on signal 15 Jan 22 23:23:03 dual pppd[7941]: Connect time 92.2 minutes. Jan 22 23:23:03 dual pppd[7941]: Sent 1322316 bytes, received 8587156 bytes. Jan 22 23:23:03 dual pppd[7941]: Connection terminated. Jan 22 23:23:05 dual kernel: usb 3-2: USB disconnect, address 5 Jan 22 23:23:05 dual kernel: option 3-2:1.0: device disconnected Jan 22 23:23:05 dual kernel: option1 ttyUSB1: GSM modem (1-port) converter now disconnected from ttyUSB1 Jan 22 23:23:05 dual kernel: option 3-2:1.1: device disconnected Jan 22 23:23:13 dual kernel: unregister_netdevice: waiting for ppp0 to become free. Usage count = 1 Jan 22 23:23:44 dual last message repeated 3 times Jan 22 23:23:54 dual kernel: unregister_netdevice: waiting for ppp0 to become free. Usage count = 1
2.6.24-rc7 works fine, not yet bisected, will do later in the evening.
Signature · 1 line
maks
Quoted 14 lines · maximilian attems
when killing a wvdial usb modem session:
Jan 22 23:23:03 dual pppd[7941]: Terminating on signal 15 Jan 22 23:23:03 dual pppd[7941]: Connect time 92.2 minutes. Jan 22 23:23:03 dual pppd[7941]: Sent 1322316 bytes, received 8587156 bytes. Jan 22 23:23:03 dual pppd[7941]: Connection terminated. Jan 22 23:23:05 dual kernel: usb 3-2: USB disconnect, address 5 Jan 22 23:23:05 dual kernel: option 3-2:1.0: device disconnected Jan 22 23:23:05 dual kernel: option1 ttyUSB1: GSM modem (1-port) converter now disconnected from ttyUSB1 Jan 22 23:23:05 dual kernel: option 3-2:1.1: device disconnected Jan 22 23:23:13 dual kernel: unregister_netdevice: waiting for ppp0 to become free. Usage count = 1 Jan 22 23:23:44 dual last message repeated 3 times Jan 22 23:23:54 dual kernel: unregister_netdevice: waiting for ppp0 to become free. Usage count = 1
This is a known bug which doesn't just affect PPP:
<http://bugzilla.kernel.org/show_bug.cgi?id=9778>.
Ben.
Signature · 2 lines
Ben Hutchings, Senior Software Engineer, Solarflare Communications Not speaking for my employer; that's the marketing department's job.
David Miller
maintainerFrom: maximilian attems <[email protected]>
Date: Wed, 23 Jan 2008 10:35:09 +0100
Quoted 1 line
Jan 22 23:23:54 dual kernel: unregister_netdevice: waiting for ppp0 to become free. Usage count = 1
Already fixed by:
[NEIGH]: Revert 'Fix race between neigh_parms_release and neightbl_fill_parms'
Commit 9cd40029423701c376391da59d2c6469672b4bed (Fix race between neigh_parms_release and neightbl_fill_parms) introduced device reference counting regressions for several people, see:
http://bugzilla.kernel.org/show_bug.cgi?id=9778
for example.
net/core/neighbour.c +2 -2
@@ -1316,6 +1316,8 @@ void neigh_parms_release(struct neigh_table *tbl, struct neigh_parms *parms) *p = parms->next; parms->dead =1 ;write_unlock_bh (&tbl->lock); +if (parms->dev) +dev_put (parms->dev);call_rcu (&parms->rcu_head, neigh_rcu_free_parms);return ; }
@@ -1326,8 +1328,6 @@ void neigh_parms_release(struct neigh_table *tbl, struct neigh_parms *parms)void neigh_parms_destroy (struct neigh_parms *parms) { -if (parms->dev) -dev_put (parms->dev);kfree (parms); }
Quoted 7 lines · David Miller
From: maximilian attems <[email protected]>
Date: Wed, 23 Jan 2008 10:35:09 +0100Quoted 1 line
Jan 22 23:23:54 dual kernel: unregister_netdevice: waiting for ppp0 to become free. Usage count = 1Already fixed by:
thanks.
Signature · 1 line
maks
Quoted 5 lines · maximilian attems
Jan 22 23:23:13 dual kernel: unregister_netdevice: waiting for ppp0 to become free. Usage count = 1 Jan 22 23:23:44 dual last message repeated 3 times Jan 22 23:23:54 dual kernel: unregister_netdevice: waiting for ppp0 to become free. Usage count = 12.6.24-rc7 works fine, not yet bisected, will do later in the evening.
Fix (revert) is in Dave's tree already.
Signature · 1 line
Evgeniy Polyakov